leaftools.Leaf
==============

.. inheritance-diagram:: abjad.tools.leaftools.Leaf.Leaf.Leaf
   :private-bases:

.. autoclass:: abjad.tools.leaftools.Leaf.Leaf.Leaf

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.duration_in_seconds

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.format

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.leaf_index

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.multiplied_duration

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.preprolated_duration

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.duration_multiplier

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_duration

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_at_sounding_pitch

.. autoattribute:: abjad.tools.leaftools.Leaf.Leaf.Leaf.written_pitch_indication_is_nonsemantic

Special Methods
---------------

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__and__

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__or__

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__repr__

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__str__

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__sub__

.. automethod:: abjad.tools.leaftools.Leaf.Leaf.Leaf.__xor__
